==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackConfirmationFieldFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SlackConfirmationFieldFluentImpl<A extends SlackConfirmationFieldFluent<A>> extends BaseFluent<A> implements SlackConfirmationFieldFluent<A>{
  public SlackConfirmationFieldFluentImpl() {
  }
  public SlackConfirmationFieldFluentImpl(SlackConfirmationField instance) {
    this.withDismissText(instance.getDismissText()); 
    this.withOkText(instance.getOkText()); 
    this.withText(instance.getText()); 
    this.withTitle(instance.getTitle()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String dismissText;
  private String okText;
  private String text;
  private String title;
  private Map<String,Object> additionalProperties;
  public String getDismissText() {
    return this.dismissText;
  }
  public A withDismissText(String dismissText) {
    this.dismissText=dismissText; return (A) this;
  }
  public Boolean hasDismissText() {
    return this.dismissText != null;
  }
  public String getOkText() {
    return this.okText;
  }
  public A withOkText(String okText) {
    this.okText=okText; return (A) this;
  }
  public Boolean hasOkText() {
    return this.okText != null;
  }
  public String getText() {
    return this.text;
  }
  public A withText(String text) {
    this.text=text; return (A) this;
  }
  public Boolean hasText() {
    return this.text != null;
  }
  public String getTitle() {
    return this.title;
  }
  public A withTitle(String title) {
    this.title=title; return (A) this;
  }
  public Boolean hasTitle() {
    return this.title != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SlackConfirmationFieldFluentImpl that = (SlackConfirmationFieldFluentImpl) o;
    if (dismissText != null ? !dismissText.equals(that.dismissText) :that.dismissText != null) return false;
    if (okText != null ? !okText.equals(that.okText) :that.okText != null) return false;
    if (text != null ? !text.equals(that.text) :that.text != null) return false;
    if (title != null ? !title.equals(that.title) :that.title != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(dismissText,  okText,  text,  title,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (dismissText != null) { sb.append("dismissText:"); sb.append(dismissText + ","); }
    if (okText != null) { sb.append("okText:"); sb.append(okText + ","); }
    if (text != null) { sb.append("text:"); sb.append(text + ","); }
    if (title != null) { sb.append("title:"); sb.append(title + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-monitoring-6.7.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/SlackConfirmationFieldFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SlackConfirmationFieldFluentImpl<A extends SlackConfirmationFieldFluent<A>> extends BaseFluent<A> implements SlackConfirmationFieldFluent<A>{
  public SlackConfirmationFieldFluentImpl() {
  }
  public SlackConfirmationFieldFluentImpl(SlackConfirmationField instance) {
    if (instance != null) {
      this.withDismissText(instance.getDismissText());
      this.withOkText(instance.getOkText());
      this.withText(instance.getText());
      this.withTitle(instance.getTitle());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String dismissText;
  private String okText;
  private String text;
  private String title;
  private Map<String,Object> additionalProperties;
  public String getDismissText() {
    return this.dismissText;
  }
  public A withDismissText(String dismissText) {
    this.dismissText=dismissText; return (A) this;
  }
  public Boolean hasDismissText() {
    return this.dismissText != null;
  }
  public String getOkText() {
    return this.okText;
  }
  public A withOkText(String okText) {
    this.okText=okText; return (A) this;
  }
  public Boolean hasOkText() {
    return this.okText != null;
  }
  public String getText() {
    return this.text;
  }
  public A withText(String text) {
    this.text=text; return (A) this;
  }
  public Boolean hasText() {
    return this.text != null;
  }
  public String getTitle() {
    return this.title;
  }
  public A withTitle(String title) {
    this.title=title; return (A) this;
  }
  public Boolean hasTitle() {
    return this.title != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SlackConfirmationFieldFluentImpl that = (SlackConfirmationFieldFluentImpl) o;
    if (!java.util.Objects.equals(dismissText, that.dismissText)) return false;

    if (!java.util.Objects.equals(okText, that.okText)) return false;

    if (!java.util.Objects.equals(text, that.text)) return false;

    if (!java.util.Objects.equals(title, that.title)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(dismissText,  okText,  text,  title,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (dismissText != null) { sb.append("dismissText:"); sb.append(dismissText + ","); }
    if (okText != null) { sb.append("okText:"); sb.append(okText + ","); }
    if (text != null) { sb.append("text:"); sb.append(text + ","); }
    if (title != null) { sb.append("title:"); sb.append(title + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
